# -*- coding: utf-8 -*-

# Copyright © Spyder Project Contributors
# Licensed under the terms of the MIT License
# (see spyder/__init__.py for details)


class MessageKind:
    """JSON-RPC Message types."""
    REQUEST = 1
    RESPONSE = 2
    NOTIFICATION = 3
